Pumphandle
==========
A (very) work in progress collection of tools for computational and mathematical
Epidemiology.

Contents
--------
Under development


Versions
--------
0.0.1a - Initial PyPi release version.


Version Notes
-------------
0.0.1a - This release is intended primarily to make the developers life slightly easier by packaging a commonly used function for repeated use. It's not a general-purpose release, and unless you really hate writing very short bits of requests code, it's likely not worth your trouble.


Why 'Pumphandle'?
-----------------
The repository name is a reference to John Snow[1] and the Broad Street Pump

[1]: http://en.wikipedia.org/wiki/John_Snow_(physician) "John Snow"
